@@ -1,4 +1,5 @@
 from typing import Dict, Any
+import json
 
 
 class ResponseMessage:
@@ -17,6 +18,13 @@ class ResponseMessage:
         result: str
             The result provided by the entity
         """
+        # The time-out case seems to be handled by the Functions-Host, so
+        # its result is not doubly-serialized. In this branch, we compensate
+        # for this by re-serializing the payload.
+        if result.strip().startswith("Timeout value of"):
+            is_exception = True
+            result = json.dumps(result)
+
         self.result = result
         self.is_exception = is_exception
         # TODO: JS has an additional exceptionType field, but does not use it
